#
# This is the SPEC file for creating binary RPMs for the Dom0.
#
#
# The Qubes OS Project, http://www.qubes-os.org
#
# Copyright (C) 2010  Joanna Rutkowska <joanna@invisiblethingslab.com>
# Copyright (C) 2010  Rafal Wojtczuk  <rafal@invisiblethingslab.com>
#
# This library is free software; you can redistribute it and/or
# modify it under the terms of the GNU Lesser General Public
# License as published by the Free Software Foundation; either
# version 2.1 of the License, or (at your option) any later version.
#
# This library is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
# Lesser General Public License for more details.
#
# You should have received a copy of the GNU Lesser General Public
# License along with this library; if not, see <https://www.gnu.org/licenses/>.
#
#

Name:		qubes-core-qrexec
Version:	4.2.17
Release:	1%{dist}
Summary:	The Qubes qrexec files (common files)

Group:		Qubes
Vendor:		Invisible Things Lab
License:	GPL
URL:		https://www.qubes-os.org

BuildRequires:	gcc
BuildRequires:  python%{python3_pkgversion}-devel
BuildRequires:  python%{python3_pkgversion}-setuptools
# for building documentation
BuildRequires:	python3dist(sphinx)
BuildRequires:	python%{python3_pkgversion}-recommonmark
BuildRequires:	qubes-libvchan-devel
%if 0%{?is_opensuse}
BuildRequires:  python-rpm-macros
%else
BuildRequires:  python%{python3_pkgversion}-rpm-macros
%endif

Requires:   python%{python3_pkgversion}
Requires:   python%{python3_pkgversion}-gbulb
%if 0%{?is_opensuse}
Requires:   python%{python3_pkgversion}-pyinotify
%else
Requires:   python%{python3_pkgversion}-inotify
%endif
Conflicts:  qubes-utils-libs < 4.1.0
Conflicts:  qubes-core-agent-qrexec < 4.1.0
Conflicts:  qubes-core-dom0 < 4.1.10
Conflicts:  qubes-core-dom0-linux < 4.1.5
Conflicts:  qubes-gui-agent < 4.1.6
Conflicts:  qubes-gpg-split < 2.0.45
Conflicts:  qubes-gui-daemon < 4.1.4
Conflicts:  qubes-input-proxy < 1.0.17
Conflicts:  qubes-pdf-converter < 2.1.7
Conflicts:  qubes-usb-proxy < 1.0.28

Source0: qubes-core-qrexec-%{version}.tar.gz

%description
The Qubes qrexec files for installation on both dom0 and qube.

%package libs
Summary:    Libraries for qubes-qrexec
Conflicts:  qubes-utils-libs < 4.1.0

%description libs
Libraries for qubes-qrexec

%package devel
Summary:    Development headers for qubes-qrexec
Requires:   %{name}-libs

%description devel
Development header and files for qubes-qrexec

%prep
%setup -qn qubes-core-qrexec-%{version}

%build
%{?set_build_flags}
make all-base PYTHON=%{__python3}
make -C doc PYTHON=python3 SPHINXBUILD=sphinx-build man

%install
make install-base \
    INCLUDEDIR=%{_includedir} \
    LIBDIR=%{_libdir} \
    SYSCONFDIR=%{_sysconfdir} \
    UNITDIR=%{_unitdir} \
    PYTHON_SITEPATH=%{python3_sitelib} \
    PYTHON=%{__python3} \
    DESTDIR=$RPM_BUILD_ROOT

make -C doc \
    DESTDIR=$RPM_BUILD_ROOT \
    SPHINXBUILD=sphinx-build \
    install

mkdir -p $RPM_BUILD_ROOT/etc/qubes/rpc-config

# /qubes-rpc/policy.{Ask,Notify} intentionally points to files created at
# runtime (in /var/run)
export NO_BRP_STALE_LINK_ERROR=yes

%clean
rm -rf $RPM_BUILD_ROOT
rm -f %{name}-%{version}

%files
%defattr(-,root,root,-)

%{_bindir}/qrexec-legacy-convert
%{_bindir}/qrexec-policy-exec
%{_bindir}/qrexec-policy-agent
%{_bindir}/qrexec-policy-graph
%{_bindir}/qrexec-policy-restore
%{_bindir}/qrexec-policy-daemon
%{_bindir}/qubes-policy
%{_bindir}/qubes-policy-admin
%{_bindir}/qubes-policy-editor
%{_bindir}/qubes-policy-lint
%{_bindir}/qrexec-policy

%dir /usr/lib/qubes
/usr/lib/qubes/qubes-rpc-multiplexer
/usr/lib/qubes/qrexec-policy-agent-autostart

%dir %{_sysconfdir}/qubes
%dir %{_sysconfdir}/qubes/rpc-config
%dir %{_sysconfdir}/qubes-rpc
%{_sysconfdir}/qubes-rpc/policy.Ask
%{_sysconfdir}/qubes-rpc/policy.Notify

%{_sysconfdir}/xdg/autostart/qrexec-policy-agent.desktop

%dir %{python3_sitelib}/qrexec-*.egg-info
%{python3_sitelib}/qrexec-*.egg-info/*

%dir %{python3_sitelib}/qrexec
%dir %{python3_sitelib}/qrexec/__pycache__
%{python3_sitelib}/qrexec/__pycache__/*
%{python3_sitelib}/qrexec/__init__.py
%{python3_sitelib}/qrexec/client.py
%{python3_sitelib}/qrexec/exc.py
%{python3_sitelib}/qrexec/utils.py
%{python3_sitelib}/qrexec/server.py

%dir %{python3_sitelib}/qrexec/policy
%dir %{python3_sitelib}/qrexec/policy/__pycache__
%{python3_sitelib}/qrexec/policy/__pycache__/*
%{python3_sitelib}/qrexec/policy/__init__.py
%{python3_sitelib}/qrexec/policy/admin.py
%{python3_sitelib}/qrexec/policy/admin_client.py
%{python3_sitelib}/qrexec/policy/parser.py
%{python3_sitelib}/qrexec/policy/parser_compat.py
%{python3_sitelib}/qrexec/policy/utils.py

%dir %{python3_sitelib}/qrexec/tools
%dir %{python3_sitelib}/qrexec/tools/__pycache__
%{python3_sitelib}/qrexec/tools/__pycache__/*
%{python3_sitelib}/qrexec/tools/__init__.py
%{python3_sitelib}/qrexec/tools/qubes_policy.py
%{python3_sitelib}/qrexec/tools/qubes_policy_admin.py
%{python3_sitelib}/qrexec/tools/qubes_policy_editor.py
%{python3_sitelib}/qrexec/tools/qubes_policy_lint.py
%{python3_sitelib}/qrexec/tools/qrexec_legacy_convert.py
%{python3_sitelib}/qrexec/tools/qrexec_policy_agent.py
%{python3_sitelib}/qrexec/tools/qrexec_policy_exec.py
%{python3_sitelib}/qrexec/tools/qrexec_policy_daemon.py
%{python3_sitelib}/qrexec/tools/qrexec_policy_graph.py
%{python3_sitelib}/qrexec/tools/qrexec_policy_restore.py

%dir %{python3_sitelib}/qrexec/tests
%dir %{python3_sitelib}/qrexec/tests/__pycache__
%{python3_sitelib}/qrexec/tests/__pycache__/*
%{python3_sitelib}/qrexec/tests/__init__.py
%{python3_sitelib}/qrexec/tests/cli.py
%{python3_sitelib}/qrexec/tests/gtkhelpers.py
%{python3_sitelib}/qrexec/tests/rpcconfirmation.py
%{python3_sitelib}/qrexec/tests/policy_parser.py
%{python3_sitelib}/qrexec/tests/qrexec_policy_daemon.py
%{python3_sitelib}/qrexec/tests/qrexec_legacy_convert.py
%{python3_sitelib}/qrexec/tests/policy_cache.py
%{python3_sitelib}/qrexec/tests/policy_graph.py
%{python3_sitelib}/qrexec/tests/server.py
%{python3_sitelib}/qrexec/tests/policy_admin.py

%dir %{python3_sitelib}/qrexec/tests/socket
%dir %{python3_sitelib}/qrexec/tests/socket/__pycache__
%{python3_sitelib}/qrexec/tests/socket/__pycache__/*
%{python3_sitelib}/qrexec/tests/socket/__init__.py
%{python3_sitelib}/qrexec/tests/socket/agent.py
%{python3_sitelib}/qrexec/tests/socket/daemon.py
%{python3_sitelib}/qrexec/tests/socket/qrexec.py
%{python3_sitelib}/qrexec/tests/socket/util.py

%dir %{python3_sitelib}/qrexec/glade
%{python3_sitelib}/qrexec/glade/RPCConfirmationWindow.glade

%{_datadir}/man/man1/qubes-core-qrexec.1.gz

%files devel
%{_includedir}/qrexec.h
%{_includedir}/libqrexec-utils.h
%{_libdir}/libqrexec-utils.so

%files libs
%{_libdir}/libqrexec-utils.so.*

%changelog
* Thu Jan 18 2024 Qubes OS Team <qubes-devel@googlegroups.com>
- For complete changelog see: https://github.com/QubesOS/qubes-core-qrexec

* Thu Jan 18 2024 Marek Marczykowski-Górecki <marmarek@invisiblethingslab.com> - 171a681
- version 4.2.17

* Thu Jan 18 2024 Marek Marczykowski-Górecki <marmarek@invisiblethingslab.com> - 2e61270
- Remove leftover debug print

* Tue Nov 14 2023 Marek Marczykowski-Górecki <marmarek@invisiblethingslab.com> - 9670cb5
- version 4.2.16

* Sun Nov 12 2023 Marek Marczykowski-Górecki <marmarek@invisiblethingslab.com> - cd63c7d
- qrexec-policy-graph: make output order deterministic

* Sun Nov 12 2023 Marek Marczykowski-Górecki <marmarek@invisiblethingslab.com> - 042e885
- qrexec-policy-graph: add specific argument on the graph with --full-output

* Sun Nov 12 2023 Marek Marczykowski-Górecki <marmarek@invisiblethingslab.com> - 92980dc
- qrexec-policy-graph: fix output with --full-output

* Sun Nov 12 2023 Marek Marczykowski-Górecki <marmarek@invisiblethingslab.com> - f92f212
- qrexec-policy-graph: add basic tests

* Sun Nov 12 2023 Marek Marczykowski-Górecki <marmarek@invisiblethingslab.com> - 74c345b
- qrexec-policy-graph: print wildcard rules when specific argument requested

* Sun Nov 12 2023 Marek Marczykowski-Górecki <marmarek@invisiblethingslab.com> - c37cdf8
- qrexec-policy-graph: validate and normalize source/target arguments

* Sun Nov 05 2023 Marek Marczykowski-Górecki <marmarek@invisiblethingslab.com> - 45e7a58
- rpm: add missing directory ownership

* Sat Nov 04 2023 Marek Marczykowski-Górecki <marmarek@invisiblethingslab.com> - 9a9abdc
- rpm: adjust pyinotify pkg name for openSUSE

* Sat Nov 04 2023 Marek Marczykowski-Górecki <marmarek@invisiblethingslab.com> - b42d492
- rpm: own /etc/qubes/rpc-config dir too

* Sat Nov 04 2023 Marek Marczykowski-Górecki <marmarek@invisiblethingslab.com> - 75aa401
- rpm: do not fail the build on symlinks to /var/run

* Sat Nov 04 2023 Marek Marczykowski-Górecki <marmarek@invisiblethingslab.com> - 7b503d9
- rpm: move libqrexec-utils.so to -devel subpackage

* Sat Nov 04 2023 Marek Marczykowski-Górecki <marmarek@invisiblethingslab.com> - 8f6043d
- rpm: add missing directory ownership

* Sat Nov 04 2023 Marek Marczykowski-Górecki <marmarek@invisiblethingslab.com> - 9c4c3af
- rpm: adjust BR: python-rpm-macros for opneSUSE

* Sat Nov 04 2023 Marek Marczykowski-Górecki <marmarek@invisiblethingslab.com> - cd86f24
- rpm: use virtual provides python3dist(sphinx)

* Fri Nov 03 2023 Frédéric Pierret (fepitre) <frederic.pierret@qubes-os.org> - cbb90ba
- Add dedicated PAM file for Gentoo

* Thu Nov 02 2023 Marek Marczykowski-Górecki <marmarek@invisiblethingslab.com> - d92f989
- rpm: drop unused BR: python3-dbus

* Thu Nov 02 2023 Marek Marczykowski-Górecki <marmarek@invisiblethingslab.com> - ec5aa1b
- rpm: use https URL

* Tue Oct 24 2023 Marek Marczykowski-Górecki <marmarek@invisiblethingslab.com> - dab7a28
- qrexec-policy-graph: fix handling of default target

* Tue Oct 24 2023 Ben Grande <ben.grande.b@gmail.com> - 3720ecb
- Add missing dependency inotify

* Sun Oct 22 2023 Marek Marczykowski-Górecki <marmarek@invisiblethingslab.com> - 0c5d8bc
- version 4.2.15

* Sun Oct 22 2023 Marek Marczykowski-Górecki <marmarek@invisiblethingslab.com> - a9f9c2b
- ci: fixup coverage data collection

* Fri Oct 20 2023 Demi Marie Obenour <demi@invisiblethingslab.com> - 5ba4a8d
- Don't wait for stdin if there is unsent prefix data

* Fri Oct 20 2023 Marek Marczykowski-Górecki <marmarek@invisiblethingslab.com> - e1553db
- ci: upload gcov coverage data too

* Thu Oct 12 2023 Marek Marczykowski-Górecki <marmarek@invisiblethingslab.com> - d0cbbfb
- version 4.2.14

* Thu Oct 12 2023 Marta Marczykowska-Górecka <marmarta@invisiblethingslab.com> - 654e3e0
- Fix conversion rules for input policy

* Tue Oct 10 2023 Marek Marczykowski-Górecki <marmarek@invisiblethingslab.com> - 96dbbf7
- version 4.2.13

* Tue Oct 10 2023 Marta Marczykowska-Górecka <marmarta@invisiblethingslab.com> - 2849c90
- Tests for legacy policy convert tool

* Tue Oct 10 2023 Marta Marczykowska-Górecka <marmarta@invisiblethingslab.com> - 8988142
- Modify qrexec-policy-graph for more flexibility

* Fri Oct 06 2023 Marek Marczykowski-Górecki <marmarek@invisiblethingslab.com> - 28c1504
- Adjust pylint config

* Fri Oct 06 2023 Marek Marczykowski-Górecki <marmarek@invisiblethingslab.com> - 51c6309
- version 4.2.12

* Mon Sep 25 2023 Marta Marczykowska-Górecka <marmarta@invisiblethingslab.com> - b570f1f
- Add a tool to convert legacy policy files to new format

* Tue Sep 19 2023 Demi Marie Obenour <demi@invisiblethingslab.com> - 0fa8ecc
- Ensure that VLAs do not creep back into the code

* Tue Sep 19 2023 Demi Marie Obenour <demi@invisiblethingslab.com> - 0f51d6d
- Allow specifying a username in service config

* Mon Sep 18 2023 Marek Marczykowski-Górecki <marmarek@invisiblethingslab.com> - 02ff1aa
- Fix qrexec-policy-graph tool

* Fri Sep 15 2023 Demi Marie Obenour <demi@invisiblethingslab.com> - a073c30
- Prepare for parsing username from service config

* Fri Sep 15 2023 Demi Marie Obenour <demi@invisiblethingslab.com> - 174a501
- qrexec-fork-server: validate data from qrexec-agent

* Fri Sep 15 2023 Demi Marie Obenour <demi@invisiblethingslab.com> - 32719f2
- Use _exit(), not exit(), in child process after fork

* Fri Sep 15 2023 Demi Marie Obenour <demi@invisiblethingslab.com> - 955c3ec
- Add a missing printf attribute

* Sat Sep 09 2023 Marek Marczykowski-Górecki <marmarek@invisiblethingslab.com> - 5f68a98
- version 4.2.11

* Thu Sep 07 2023 Frédéric Pierret (fepitre) <frederic@invisiblethingslab.com> - 776f694
- Support for Fedora 39

* Sat Sep 02 2023 Marek Marczykowski-Górecki <marmarek@invisiblethingslab.com> - 2c060ef
- version 4.2.10

* Sat Sep 02 2023 Marek Marczykowski-Górecki <marmarek@invisiblethingslab.com> - 8cf1a6b
- Add connection timeout on the VM side too

* Sun Aug 27 2023 Ben Grande <ben.grande.b@gmail.com> - 42c8574
- Add lint and editor policy tools

* Sat Aug 26 2023 Marek Marczykowski-Górecki <marmarek@invisiblethingslab.com> - 79609b1
- version 4.2.9

* Sat Aug 19 2023 Marek Marczykowski-Górecki <marmarek@invisiblethingslab.com> - 697084f
- policy/admin: fix handling missing 'qubes' group

* Sat Aug 19 2023 Marek Marczykowski-Górecki <marmarek@invisiblethingslab.com> - 9fdf915
- Fix issues in qrexec-policy-agent found by pylint

* Sat Aug 19 2023 Marek Marczykowski-Górecki <marmarek@invisiblethingslab.com> - 3407618
- cleanup pylintrc

